@@ -14,8 +14,7 @@ def login(project, retries=2):
     if not usr:
         return login(project, retries-1)
     pwd = getpass.getpass()
-    resp = push_json(url, {'username': usr, 'password': pwd}, None)
-    logging.debug(resp.json())
+    resp = push_json(url, {'username': usr, 'password': pwd}, None, no_raise_for=[401, 402])
     if resp.status_code in (401, 402):
         print('Sorry. Try again.')
         return login(project, retries-1)
@@ -26,9 +25,11 @@ def push_url(project, user):
     return project.schema_server_url + '/repo/' + user + '/' + project.name + '/image'
 
 
-def push_json(url, data, session_id):
-    headers = {'Content-Type': 'application/json',
-               'Session-ID': session_id}
-    response = requests.post(url, json.dumps(data), headers=headers, verify=False)
-    response.raise_for_status()
+def push_json(url, data, session_id, no_raise_for=tuple()):
+    headers = {'Content-Type': 'application/json'}
+    if session_id:
+        headers['session-id'] = session_id
+    response = requests.post(url, json.dumps(data), headers=headers)
+    if response.status_code not in no_raise_for:
+        response.raise_for_status()
     return response
