@@ -10,9 +10,7 @@ from sbdk.docker import make_runner
 
 def argument_parser(subparsers):
     parser = subparsers.add_parser("push", help="Create new image and upload it")
-
     parser.set_defaults(func=push)
-
     parser.add_argument('message', help='Short description of your changes')
 
 
@@ -28,8 +26,10 @@ def push(project, message):
         container.print_log()
         exit("Push command failed")
     config = {'Cmd': project.sdk_runner_command, 'Entrypoint': project.docker_entrypoint}
-    container.load_credentials()
+    container.load_credentials(renew=True)
     container.commit(message, config).push()
+    # if not check_container_push(container):
+    #     raise Exception('Push failed, image not found in registry. try again?')
     push_schema(project, container)
     container.remove()
 
@@ -62,4 +62,12 @@ def push_schema(project, container):
                 container.load_credentials(renew=True)
                 push_json(url, push_data, container.token)
             else:
-                raise e
\ No newline at end of file
+                raise e
+
+
+def check_container_push(container):
+    docker_repo, image_id = container.repository, container.image['Id']
+    resp = requests.get('https://%s/v1/%s/%s/images' % docker_repo.split('/'))
+    if resp.status_code != 200:
+        raise Exception('Bad response (%s) : %s' % (resp.status_code, resp.content))
+    return image_id in [i['id'] for i in resp.json()]
