@@ -74,8 +74,8 @@ class Container(object):
         self.wait()
         self.docker.remove_container(self.container)
 
-    def stop(self):
-        return self.docker.stop(self.container)
+    def stop(self, nice=False):
+        return self.docker.stop(self.container) if nice else self.docker.kill(self.container)
 
     def print_log(self):
         if self.is_running():
