@@ -4,7 +4,7 @@ import sys
 import argparse
 import logging
 
-from sbdk.commands import init, push, test, sh, run, show_settings, schema, cf, fix_uid, upload
+from sbdk.commands import init, push, test, sh, run, show_settings, schema, fix_uid, upload
 from sbdk.error import SbdkError
 from sbdk.project import Project
 from sbdk import VERSION
@@ -23,7 +23,7 @@ def main(argv=None, context=None):
                         help='Increase output verbosity')
 
     subparsers = parser.add_subparsers()
-    commands = [init, test, push, sh, run, show_settings, schema, fix_uid, upload, cf]
+    commands = [init, test, push, sh, run, show_settings, schema, fix_uid, upload]
     for cmd in commands:
         cmd.argument_parser(subparsers)
 
