@@ -1,4 +1,4 @@
-from attrdef import AttrDef
+from .attrdef import AttrDef
 
 
 def default_attr_name(name):
